@@ -3,7 +3,7 @@
 Company: eXonware.com
 Author: Eng. Muhammad AlShehri
 Email: connect@exonware.com
-Version: 0.0.1.362
+Version: 0.0.1.375
 Generation Date: September 04, 2025
 
 Automatic serializer that detects format and delegates to appropriate serializer.
@@ -95,7 +95,8 @@ class AutoSerializer:
                               fromlist=[class_name])
             return getattr(module, class_name)
         except (ImportError, AttributeError) as e:
-            raise ImportError(f"Serializer for {format_name} not available: {e}")
+            # Lazy installation system will handle missing dependencies
+            raise ImportError(f"Serializer for {format_name} failed to load: {e}")
     
     def _get_serializer(self, format_name: str) -> ISerialization:
         """
